#include <QApplication>
#include <QWidget>
#include <QGraphicsDropShadowEffect>
#include <QVBoxLayout>
#include <QScrollArea>
#include <QPushButton>
#include <QDebug>


class MyButton : public QPushButton
{
   using QPushButton::QPushButton;
protected:
   void paintEvent(QPaintEvent *event) override;
};

void MyButton::paintEvent(QPaintEvent *event)
{
   if (objectName() == QString("PUSHBUTTON3")) {
      qDebug() << "PAINT EVENT";
   }
   QPushButton::paintEvent(event);
}

int main(int argc, char **argv)
{
   QGuiApplication::setAttribute( Qt::AA_EnableHighDpiScaling );

   QApplication app(argc, argv);

   QWidget outer;
   outer.setObjectName("OUTER");
   QVBoxLayout *layout = new QVBoxLayout(&outer);
   layout->setMargin(50);

   QScrollArea *area = new QScrollArea(&outer);
   area->setObjectName("AREA");
   area->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
   layout->addWidget(area);

   {
      QGraphicsDropShadowEffect *effect = new QGraphicsDropShadowEffect(area);
      effect->setColor(Qt::yellow);
      effect->setXOffset(10);
      effect->setYOffset(10);
      effect->setBlurRadius(0);
      area->setGraphicsEffect(effect);
   }

   QWidget *contentWidget = new QWidget;
   contentWidget->setObjectName("CONTENT");
   QPalette pal = contentWidget->palette();
   pal.setBrush(QPalette::Background, Qt::red);
   contentWidget->setPalette(pal);
   area->setWidgetResizable(true);
   area->setWidget(contentWidget);

   QVBoxLayout *contentLayout = new QVBoxLayout(contentWidget);
   contentLayout->setSpacing(0);
   contentLayout->setMargin(0);
   for (int i = 0; i < 5; ++i) {
      QPushButton *pb = new MyButton(contentWidget);
      pb->setObjectName("PUSHBUTTON" + QString::number(i));
      pb->setFixedHeight(100);
      contentLayout->addWidget(pb);
   }

   outer.show();

   return app.exec();
}
